import { TransactionBuilder } from '@orca-so/common-sdk';
import { Keypair, PublicKey, TransactionInstruction } from '@solana/web3.js';
import SafeFinder from '../services/safe-finder';
import { Program } from '@project-serum/anchor';
import { InstructionBuilder } from '../builders/instruction-builder';
import { MultisigJob, SafeType, SerializableAction } from '../models';
import { Context } from './context';
import BN from 'bn.js';
export declare function deriveATA(ownerAddress: PublicKey, tokenMint: PublicKey): Promise<PublicKey>;
export declare class SafeClient {
    ctx: Context;
    program: Program;
    instructionBuilder: InstructionBuilder;
    wallet: PublicKey;
    fetcher: SafeFinder;
    constructor(ctx: Context);
    static getSpendingLimitSignerAddress(ctx: Context, spendingLimit: PublicKey): Promise<PublicKey>;
    static createSpendingLimit(ctx: Context, index: number, name: string, safeAddress: PublicKey, tokenAddress: PublicKey, amount: BN, period: BN, spenders: PublicKey[]): Promise<TransactionBuilder>;
    static rmSpendingLimit(ctx: Context, safeAddress: PublicKey, spendingLimitAddress: PublicKey): Promise<TransactionBuilder>;
    static updateSpendingLimit(ctx: Context, safeAddress: PublicKey, spendingLimitAddress: PublicKey, name: string, amount: BN, period: BN, spenders: PublicKey[]): Promise<TransactionBuilder>;
    static withdrawToken(ctx: Context, spendingLimitAddress: PublicKey, mintAddress: PublicKey, amount: BN): Promise<TransactionBuilder>;
    static withdrawTokenByOwner(ctx: Context, spendingLimitAddress: PublicKey, safeSignerAddress: PublicKey, mintAddress: PublicKey, amount: BN): Promise<TransactionBuilder>;
    static create(ctx: Context, owners: PublicKey[], approvalsRequired: number): Promise<TransactionBuilder>;
    createProposal(safeAddress: PublicKey, proposalName: string, proposalInstructions: TransactionInstruction[], setupInstructions?: TransactionInstruction[], accountSize?: number, isDraft?: boolean, isApproved?: boolean, separatedActions?: boolean): Promise<[PublicKey, TransactionBuilder]>;
    approveProposal(proposalAddress: PublicKey): Promise<TransactionBuilder>;
    rejectProposal(proposalAddress: PublicKey): Promise<TransactionBuilder>;
    createRecurringProposalInstructions(safeAddress: PublicKey, proposalKeypair: Keypair, proposal: MultisigJob, setupInstructions?: TransactionInstruction[], accountSize?: number, isDraft?: boolean, isApproved?: boolean, separatedActions?: boolean): Promise<TransactionInstruction[]>;
    createAddProposalActionInstructions(proposalAddress: PublicKey, proposalActions: SerializableAction[]): Promise<TransactionInstruction[]>;
    executeProposal(proposalAddress: PublicKey): Promise<TransactionBuilder>;
    addOwnerProposal(safeAddress: PublicKey, newOwners: PublicKey[], newThreshold: number | undefined): Promise<[PublicKey, TransactionBuilder]>;
    removeOwnerProposal(safeAddress: PublicKey, safeOwner: PublicKey): Promise<[PublicKey, TransactionBuilder]>;
    fetchOwnedSafes(ownerAddress: PublicKey): Promise<SafeType[]>;
    fetchProposal(proposalAddress: PublicKey): Promise<MultisigJob>;
    fetchAllProposals(safeAddress: PublicKey): Promise<MultisigJob[]>;
    fetchDerivedSafeAddress(proposalAddress: PublicKey): Promise<PublicKey>;
    fetchSafe(safeAddress: PublicKey): Promise<SafeType>;
    static findSafeSignerAddress(safeAddress: PublicKey, safeProgramId: PublicKey): Promise<[PublicKey, number]>;
    findSafeSignerAddress(safeAddress: PublicKey): Promise<[PublicKey, number]>;
    static buildTx(ctx: Context, instructions: TransactionInstruction[], signers?: Keypair[]): TransactionBuilder;
    private buildProposal;
}
